import java.awt.*;
import java.awt.event.*;
import java.awt.datatransfer.*;

/**
 * Password: A simple (strong) password generator that gives its output
 * to both the screen and windows clipboard
 * 
 * If you use these functions or learn from them, please let me know.  I
 * don't mind if you blatantly steal them, just give me some feedback!
 *
 * Lee Holmes - lee@leeholmes.com, Feb 01 2001
 * PGP Key ID: 0x12FD260B
 * 
**/
class Password extends Frame implements ClipboardOwner
{
	public static void main (String args[])	
	{
		int passwordLength = 8;

		// Check if we got some command line parameters
		if(args.length > 0)
		{
			try
			{
				passwordLength = Integer.parseInt(args[0]);
			}
			catch(Exception e)
			{
				System.out.println("\nUsage: Password [password length]");
				System.out.println("If a password length is not specified, Password generates an 8 character password.");

				return;
			}
		}

		Password newPassword = new Password(passwordLength);
		System.exit(0);
	}
	
	/**
	 * Generates a password -- then prints it to the screen and puts it into the
	 * clipboard
	 * 
	 * @param int passwordLength - The length of the password to generate
	 * 
	**/
	Password(int passwordLength)
	{
		String password = generatePassword(passwordLength);

		Clipboard clipboard = getToolkit().getSystemClipboard();
		StringSelection contents = new StringSelection(password);
    clipboard.setContents(contents, this);
                
		System.out.print(password);
	} // finish Password(int passwordLength)

	// Function to generate a single random character for a password
	char getLetter()
	{
		// Hold the array of all valid letters for a password
		String lettersArray = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789`~!@#$%^&*()[{]}\\|-_/?=+";

		// Get the index of the letter in the array we will return
		int letterIndex = (int) Math.floor(Math.random() * lettersArray.length());

		// Return the actual letter
		return lettersArray.charAt(letterIndex);
	}

	// Function to generate a random password of length 'length'
	String generatePassword(int length)
	{
		StringBuffer newPassword = new StringBuffer();

		// Generate the password: x letters taken randomly from getLetter
		for(int x = 0; x < length; x++)
		{
			newPassword.append(getLetter());
		}

		return new String(newPassword);
	}

	// Define this method so that we can use ourself as a ClipBoardOwner class
  public void lostOwnership(Clipboard clipboard, Transferable contents) 
	{
  }

}// finish class Password
	
